@@ -5,6 +5,7 @@ import asyncio
 import json
 import os
 import sys
+from typing import Optional
 
 from PySide6.QtGui import QIcon
 from PySide6.QtWidgets import QApplication, QMessageBox
@@ -18,6 +19,7 @@ from systembridgeshared.exceptions import (
 )
 from systembridgeshared.logger import setup_logger
 from systembridgeshared.models.media_play import MediaPlay
+from systembridgeshared.models.notification import Notification
 from systembridgeshared.settings import Settings
 from systembridgeshared.websocket_client import WebSocketClient
 from typer import Typer
@@ -26,6 +28,7 @@ from systembridgegui._version import __version__
 from systembridgegui.system_tray import SystemTray
 from systembridgegui.widgets.timed_message_box import TimedMessageBox
 from systembridgegui.window.main import MainWindow
+from systembridgegui.window.notification import NotificationWindow
 from systembridgegui.window.player import PlayerWindow
 
 
@@ -36,7 +39,7 @@ class Main(Base):
         self,
         command: str = "main",
         gui_only: bool = False,
-        data: dict | None = None,
+        data: Optional[dict] = None,
     ) -> None:
         """Initialize"""
         super().__init__()
@@ -119,6 +122,18 @@ class Main(Base):
                 "video",
                 media_play,
             )
+        elif command == "notification":
+            self._logger.info("Notification")
+            if data is None:
+                self._logger.error("No data provided!")
+                self._startup_error("No data provided!")
+                sys.exit(1)
+            self._player_window = NotificationWindow(
+                self._settings,
+                self._icon,
+                self._application,
+                Notification(**data),
+            )
 
         sys.exit(self._application.exec())
 
@@ -130,8 +145,8 @@ class Main(Base):
         self,
         path: str,
         maximized: bool,
-        width: int | None = 1280,
-        height: int | None = 720,
+        width: Optional[int] = 1280,
+        height: Optional[int] = 720,
     ) -> None:
         """Show the main window"""
         self._logger.info("Showing window: %s", path)
@@ -220,6 +235,14 @@ def media_player(
     Main(command=f"media-player-{media_type}", data=json.loads(data))
 
 
+@app.command(name="notification", help="Show a notification")
+def notification(
+    data: str,
+) -> None:
+    """Show a notification"""
+    Main(command="notification", data=json.loads(data))
+
+
 if __name__ == "__main__":
     asyncio.set_event_loop(asyncio.new_event_loop())
     database = Database()
